@@ -8,10 +8,11 @@ $type live, vod
 import logging
 import re
 from collections import deque
-from datetime import datetime, timedelta
+from dataclasses import dataclass
+from datetime import datetime, timedelta, timezone
 from random import randint
 from threading import Event, RLock
-from typing import Any, Callable, Deque, Dict, List, NamedTuple, Optional, Union
+from typing import Any, Callable, Deque, Dict, List, Optional, Union
 from urllib.parse import urljoin, urlunparse
 
 from requests import Response
@@ -21,7 +22,7 @@ from streamlink.plugin import Plugin, pluginargument, pluginmatcher
 from streamlink.plugin.api import useragents, validate
 from streamlink.plugin.api.websocket import WebsocketClient
 from streamlink.stream.ffmpegmux import MuxedStream
-from streamlink.stream.segmented import SegmentedStreamReader, SegmentedStreamWorker, SegmentedStreamWriter
+from streamlink.stream.segmented import Segment, SegmentedStreamReader, SegmentedStreamWorker, SegmentedStreamWriter
 from streamlink.stream.stream import Stream
 from streamlink.utils.parse import parse_json
 
@@ -29,28 +30,27 @@ from streamlink.utils.parse import parse_json
 log = logging.getLogger(__name__)
 
 
-# TODO: use dataclasses for stream formats after dropping py36 to be able to subclass
-class StreamFormatVideo(NamedTuple):
+@dataclass
+class _StreamFormat:
     contentType: str
     sourceStreamVersion: int
     initUrl: str
     segmentUrl: str
     bitrate: int
+
+
+@dataclass
+class StreamFormatVideo(_StreamFormat):
     height: int
 
 
-class StreamFormatAudio(NamedTuple):
-    contentType: str
-    sourceStreamVersion: int
-    initUrl: str
-    segmentUrl: str
-    bitrate: int
+@dataclass
+class StreamFormatAudio(_StreamFormat):
     language: str = ""
 
 
-class Segment(NamedTuple):
-    num: int
-    duration: int
+@dataclass
+class UStreamTVSegment(Segment):
     available_at: datetime
     hash: str
     path: str
@@ -59,7 +59,7 @@ class Segment(NamedTuple):
     def url(self, base: Optional[str], template: str) -> str:
         return urljoin(
             base or "",
-            f"{self.path}/{template.replace('%', str(self.num), 1).replace('%', self.hash, 1)}"
+            f"{self.path}/{template.replace('%', str(self.num), 1).replace('%', self.hash, 1)}",
         )
 
 
@@ -85,7 +85,7 @@ class UStreamTVWsClient(WebsocketClient):
                     "bitrate": int,
                     "height": int,
                 },
-                validate.transform(lambda obj: StreamFormatVideo(**obj))
+                validate.transform(lambda obj: StreamFormatVideo(**obj)),
             ),
             validate.all(
                 {
@@ -96,10 +96,10 @@ class UStreamTVWsClient(WebsocketClient):
                     "bitrate": int,
                     validate.optional("language"): str,
                 },
-                validate.transform(lambda obj: StreamFormatAudio(**obj))
+                validate.transform(lambda obj: StreamFormatAudio(**obj)),
             ),
-            object
-        )]
+            object,
+        )],
     })
     _schema_stream_segments = validate.Schema({
         "chunkId": int,
@@ -108,13 +108,13 @@ class UStreamTVWsClient(WebsocketClient):
             {
                 "accessList": [{
                     "data": {
-                        "path": str
-                    }
-                }]
+                        "path": str,
+                    },
+                }],
             },
-            validate.get(("accessList", 0, "data", "path"))
+            validate.get(("accessList", 0, "data", "path")),
         ),
-        "hashes": {validate.transform(int): str}
+        "hashes": {validate.transform(int): str},
     })
 
     stream_cdn: Optional[str] = None
@@ -131,14 +131,14 @@ class UStreamTVWsClient(WebsocketClient):
         cluster="live",
         password=None,
         app_id=APP_ID,
-        app_version=APP_VERSION
+        app_version=APP_VERSION,
     ) -> None:
         self.opened = Event()
         self.ready = Event()
         self.stream_error = None
         # a list of deques subscribed by worker threads which independently need to read segments
-        self.stream_segments_subscribers: List[Deque[Segment]] = []
-        self.stream_segments_initial: Deque[Segment] = deque()
+        self.stream_segments_subscribers: List[Deque[UStreamTVSegment]] = []
+        self.stream_segments_initial: Deque[UStreamTVSegment] = deque()
         self.stream_segments_lock = RLock()
 
         self.media_id = media_id
@@ -168,7 +168,7 @@ class UStreamTVWsClient(WebsocketClient):
                 log.info("Closing websocket connection")
                 self.ws.close()
 
-    def segments_subscribe(self) -> Deque[Segment]:
+    def segments_subscribe(self) -> Deque[UStreamTVSegment]:
         with self.stream_segments_lock:
             # copy the initial segments deque (segments arrive early)
             new_deque = self.stream_segments_initial.copy()
@@ -176,7 +176,7 @@ class UStreamTVWsClient(WebsocketClient):
 
             return new_deque
 
-    def _segments_append(self, segment: Segment):
+    def _segments_append(self, segment: UStreamTVSegment):
         # if there are no subscribers yet, add segment(s) to the initial deque
         if not self.stream_segments_subscribers:
             self.stream_segments_initial.append(segment)
@@ -194,14 +194,14 @@ class UStreamTVWsClient(WebsocketClient):
             "referrer": self.referrer,
             "clusterHost": "r%rnd%-1-%mediaId%-%mediaType%-%protocolPrefix%-%cluster%.ums.ustream.tv",
             "media": self.media_id,
-            "application": self.application
+            "application": self.application,
         }
         if self.password:
             args["password"] = self.password
 
         self.send_json({
             "cmd": "connect",
-            "args": [args]
+            "args": [args],
         })
 
     def on_message(self, wsapp, data: str):
@@ -252,7 +252,7 @@ class UStreamTVWsClient(WebsocketClient):
             data["protocol"],
             data["data"][0]["data"][0]["sites"][0]["host"],
             data["data"][0]["data"][0]["sites"][0]["path"],
-            "", "", ""
+            "", "", "",
         ))
         self._set_ready()
 
@@ -295,7 +295,7 @@ class UStreamTVWsClient(WebsocketClient):
         if self.stream_initial_id is None:
             self.stream_initial_id = current_id
 
-        current_time = datetime.now()
+        current_time = datetime.now(timezone.utc)
 
         # lock the stream segments deques for the worker threads
         with self.stream_segments_lock:
@@ -308,12 +308,13 @@ class UStreamTVWsClient(WebsocketClient):
                     # the last id->hash item will use the previous diff to extrapolate segment IDs
                     diff = sorted_ids[idx_next] - segment_id
                 for num in range(segment_id, segment_id + diff):
-                    self._segments_append(Segment(
+                    self._segments_append(UStreamTVSegment(
+                        uri="",
                         num=num,
                         duration=duration,
                         available_at=current_time + timedelta(seconds=(num - current_id - 1) * duration / 1000),
                         hash=hashes[segment_id],
-                        path=path
+                        path=path,
                     ))
 
         self._set_ready()
@@ -333,11 +334,11 @@ class UStreamTVWsClient(WebsocketClient):
         "moduleInfo": {
             "cdnConfig": _handle_module_info_cdn_config,
             "stream": _handle_module_info_stream,
-        }
+        },
     }
 
 
-class UStreamTVStreamWriter(SegmentedStreamWriter):
+class UStreamTVStreamWriter(SegmentedStreamWriter[UStreamTVSegment, Response]):
     reader: "UStreamTVStreamReader"
     stream: "UStreamTVStream"
 
@@ -358,11 +359,11 @@ class UStreamTVStreamWriter(SegmentedStreamWriter):
             self.queue(segment, self.executor.submit(self.fetch, segment, False))
 
     # noinspection PyMethodOverriding
-    def fetch(self, segment: Segment, is_init: bool):  # type: ignore[override]
+    def fetch(self, segment: UStreamTVSegment, is_init: bool):  # type: ignore[override]
         if self.closed:  # pragma: no cover
             return
 
-        now = datetime.now()
+        now = datetime.now(timezone.utc)
         if segment.available_at > now:
             time_to_wait = (segment.available_at - now).total_seconds()
             log.debug(f"Waiting for {self.stream.kind} segment: {segment.num} ({time_to_wait:.01f}s)")
@@ -373,16 +374,16 @@ class UStreamTVStreamWriter(SegmentedStreamWriter):
             return self.session.http.get(
                 segment.url(
                     self.stream.wsclient.stream_cdn,
-                    self.stream.stream_format.initUrl if is_init else self.stream.stream_format.segmentUrl
+                    self.stream.stream_format.initUrl if is_init else self.stream.stream_format.segmentUrl,
                 ),
                 timeout=self.timeout,
                 retries=self.retries,
-                exception=StreamError
+                exception=StreamError,
             )
         except StreamError as err:
             log.error(f"Failed to fetch {self.stream.kind} segment {segment.num}: {err}")
 
-    def write(self, segment: Segment, res: Response, *data):
+    def write(self, segment: UStreamTVSegment, res: Response, *data):
         if self.closed:  # pragma: no cover
             return
         try:
@@ -393,7 +394,7 @@ class UStreamTVStreamWriter(SegmentedStreamWriter):
             log.error(f"Failed to read {self.stream.kind} segment {segment.num}: {err}")
 
 
-class UStreamTVStreamWorker(SegmentedStreamWorker):
+class UStreamTVStreamWorker(SegmentedStreamWorker[UStreamTVSegment, Response]):
     reader: "UStreamTVStreamReader"
     writer: "UStreamTVStreamWriter"
     stream: "UStreamTVStream"
@@ -427,7 +428,7 @@ class UStreamTVStreamWorker(SegmentedStreamWorker):
             self.segment_id = segment.num + 1
 
 
-class UStreamTVStreamReader(SegmentedStreamReader):
+class UStreamTVStreamReader(SegmentedStreamReader[UStreamTVSegment, Response]):
     __worker__ = UStreamTVStreamWorker
     __writer__ = UStreamTVStreamWriter
 
@@ -452,7 +453,7 @@ class UStreamTVStream(Stream):
         session,
         kind: str,
         wsclient: UStreamTVWsClient,
-        stream_format: Union[StreamFormatVideo, StreamFormatAudio]
+        stream_format: Union[StreamFormatVideo, StreamFormatAudio],
     ):
         super().__init__(session)
         self.kind = kind
@@ -499,8 +500,8 @@ class UStreamTV(Plugin):
                 headers={"User-Agent": useragents.CHROME},
                 schema=validate.Schema(
                     validate.parse_html(),
-                    validate.xml_xpath_string(".//meta[@name='ustream:channel_id'][@content][1]/@content")
-                )
+                    validate.xml_xpath_string(".//meta[@name='ustream:channel_id'][@content][1]/@content"),
+                ),
             )
 
         return channel_id, "channel"
@@ -519,14 +520,15 @@ class UStreamTV(Plugin):
             application,
             referrer=self.url,
             cluster="live",
-            password=self.get_option("password")
+            password=self.get_option("password"),
         )
         log.debug(
-            f"Connecting to UStream API:"
-            f" media_id={media_id},"
-            f" application={application},"
-            f" referrer={self.url},"
-            f" cluster=live"
+            "Connecting to UStream API: " + ", ".join([
+                f"media_id={media_id}",
+                f"application={application}",
+                f"referrer={self.url}",
+                f"cluster={'live'}",
+            ]),
         )
         wsclient.start()
 
@@ -549,7 +551,7 @@ class UStreamTV(Plugin):
                     yield f"{video.height}p+a{audio.bitrate}k", MuxedStream(
                         self.session,
                         UStreamTVStream(self.session, "video", wsclient, video),
-                        UStreamTVStream(self.session, "audio", wsclient, audio)
+                        UStreamTVStream(self.session, "audio", wsclient, audio),
                     )
 
 
