@@ -1,7 +1,6 @@
 import os
 import sys
-from typing import Dict, Iterator, List, Tuple
-from unittest.mock import patch
+from typing import Dict, List, Tuple
 
 import pytest
 import requests_mock as rm
@@ -18,6 +17,7 @@ _TEST_PRIORITIES = (
     "build_backend/",
     "tests/testutils/",
     "tests/utils/",
+    "tests/session/",
     None,
     "tests/stream/",
     "tests/test_plugins.py",
@@ -67,14 +67,21 @@ def _check_test_condition(item: pytest.Item):  # pragma: no cover
 
 
 @pytest.fixture()
-def session(request: pytest.FixtureRequest) -> Iterator[Streamlink]:
-    with patch.object(Streamlink, "load_builtin_plugins"):
-        session = Streamlink()
-        for key, value in getattr(request, "param", {}).items():
-            session.set_option(key, value)
-        yield session
+def session(request: pytest.FixtureRequest, monkeypatch: pytest.MonkeyPatch):
+    options = getattr(request, "param", {})
+    plugins_builtin = options.pop("plugins-builtin", False)
+    plugins_lazy = options.pop("plugins-lazy", False)
 
-    Streamlink.resolve_url.cache_clear()
+    session = Streamlink(
+        options=options,
+        plugins_builtin=plugins_builtin,
+        plugins_lazy=plugins_lazy,
+    )
+
+    try:
+        yield session
+    finally:
+        Streamlink.resolve_url.cache_clear()
 
 
 @pytest.fixture()
