@@ -201,7 +201,7 @@ class TestMixinStreamHLS(unittest.TestCase):
         super().__init__(*args, **kwargs)
         # FIXME: fix HTTPSession.request()
         # don't sleep on mocked HTTP request failures
-        self._patch_http_retry_sleep = patch("streamlink.plugin.api.http_session.time.sleep")
+        self._patch_http_retry_sleep = patch("streamlink.session.http.time.sleep")
         self.mocker = requests_mock.Mocker()
         self.mocks = {}
 
@@ -280,7 +280,7 @@ class TestMixinStreamHLS(unittest.TestCase):
         return data
 
     def get_session(self, options=None, *args, **kwargs):
-        return Streamlink(options)
+        return Streamlink(options, plugins_builtin=False)
 
     # set up HLS responses, create the session and read thread and start it
     def subject(self, playlists, options=None, streamoptions=None, threadoptions=None, start=True, *args, **kwargs):
