@@ -2,7 +2,6 @@ import re
 from io import BytesIO
 
 from streamlink import NoStreamsError
-from streamlink.options import Options
 from streamlink.plugin import pluginargument, pluginmatcher
 from streamlink.plugins import Plugin
 from streamlink.stream.hls import HLSStream
@@ -14,11 +13,11 @@ class TestStream(Stream):
     __shortname__ = "test"
 
     def open(self):
-        return BytesIO(b'x' * 8192 * 2)
+        return BytesIO(b"x" * 8192 * 2)
 
 
 @pluginmatcher(re.compile(
-    r"https?://test\.se"
+    r"https?://test\.se",
 ))
 @pluginargument(
     "bool",
@@ -30,10 +29,6 @@ class TestStream(Stream):
     metavar="PASSWORD",
 )
 class TestPlugin(Plugin):
-    options = Options({
-        "a_option": "default"
-    })
-
     id = "test-id-1234-5678"
     author = "Tѥst Āuƭhǿr"
     category = None
@@ -45,7 +40,7 @@ class TestPlugin(Plugin):
 
         if "UnsortableStreamNames" in self.url:
             def gen():
-                for i in range(3):
+                for _ in range(3):
                     yield "vod", HTTPStream(self.session, "http://test.se/stream")
 
             return gen()
@@ -53,6 +48,9 @@ class TestPlugin(Plugin):
         if "NoStreamsError" in self.url:
             raise NoStreamsError
 
+        if "fromoptions" in self.url:
+            return {"fromoptions": HTTPStream(self.session, self.options.get("streamurl"))}
+
         streams = {}
         streams["test"] = TestStream(self.session)
         streams["hls"] = HLSStream(self.session, "http://test.se/playlist.m3u8")
@@ -69,7 +67,7 @@ class TestPlugin(Plugin):
 
         streams["480p"] = [
             HTTPStream(self.session, "http://test.se/stream"),
-            HLSStream(self.session, "http://test.se/playlist.m3u8")
+            HLSStream(self.session, "http://test.se/playlist.m3u8"),
         ]
 
         return streams
