@@ -6,6 +6,6 @@ class TestPluginCanHandleUrlYuppTV(PluginCanHandleUrl):
     __plugin__ = YuppTV
 
     should_match = [
-        'https://www.yupptv.com/channels/etv-telugu/live',
-        'https://www.yupptv.com/channels/india-today-news/news/25326023/15-jun-2018',
+        "https://www.yupptv.com/channels/etv-telugu/live",
+        "https://www.yupptv.com/channels/india-today-news/news/25326023/15-jun-2018",
     ]
