@@ -60,9 +60,8 @@ class TestInit:
 class TestLaunch:
     @pytest.mark.trio()
     async def test_terminate_on_nursery_exit(self, caplog: pytest.LogCaptureFixture, webbrowser_launch):
-        nursery: trio.Nursery
         process: trio.Process
-        async with webbrowser_launch() as (nursery, process):
+        async with webbrowser_launch() as (_nursery, process):
             assert process.poll() is None, "process is still running"
 
         assert process.poll() == (1 if is_win32 else -SIGTERM), "Process has been terminated"
@@ -85,9 +84,8 @@ class TestLaunch:
 
     @pytest.mark.trio()
     async def test_terminate_on_nursery_timeout(self, caplog: pytest.LogCaptureFixture, mock_clock, webbrowser_launch):
-        nursery: trio.Nursery
         process: trio.Process
-        async with webbrowser_launch(timeout=10) as (nursery, process):
+        async with webbrowser_launch(timeout=10) as (_nursery, process):
             assert process.poll() is None, "process is still running"
             mock_clock.jump(20)
             await trio.sleep(0)
@@ -103,10 +101,9 @@ class TestLaunch:
         class FakeBaseException(BaseException):
             pass
 
-        nursery: trio.Nursery
         process: trio.Process
         with pytest.raises(FakeBaseException):  # noqa: PT012
-            async with webbrowser_launch() as (nursery, process):
+            async with webbrowser_launch() as (_nursery, process):
                 assert process.poll() is None, "process is still running"
                 raise FakeBaseException()
 
@@ -121,9 +118,8 @@ class TestLaunch:
     # don't check for non-zero exit codes - we don't care
     @pytest.mark.parametrize("exit_code", [0, 1])
     async def test_process_ended_early(self, caplog: pytest.LogCaptureFixture, webbrowser_launch, exit_code):
-        nursery: trio.Nursery
         process: trio.Process
-        async with webbrowser_launch(timeout=10) as (nursery, process):
+        async with webbrowser_launch(timeout=10) as (_nursery, process):
             assert process.poll() is None, "process is still running"
             assert process.stdin
             await process.stdin.send_all(str(exit_code).encode() + b"\r\n")
